@@ -1,4 +1,4 @@
-# Copyright (c) 2007 by Lorenzo Gil Sanchez <lorenzo.gil.sanchez@gmail.com>
+# Copyright (c) 2007-2008 by Lorenzo Gil Sanchez <lorenzo.gil.sanchez@gmail.com>
 #
 # This file is part of PyCha.
 #
@@ -24,7 +24,7 @@ def clamp(minValue, maxValue, value):
     if value > maxValue:
         return maxValue
     return value
-    
+
 def hex2rgb(hexstring, digits=2):
     """Converts a hexstring color to a rgb tuple.
 
@@ -47,17 +47,18 @@ def lighten(r, g, b, amount):
     return (clamp(0.0, 1.0, r + amount),
             clamp(0.0, 1.0, g + amount),
             clamp(0.0, 1.0, b + amount))
-    
-def generateColorscheme(masterColor, keys, light=0.098):
+
+def generateColorscheme(masterColor, keys):
     """Generates a dictionary where the keys match the keys argument and
     the values are colors derivated from the masterColor.
 
-    Each color is a lighter version of masterColor separated by a difference
-    given by the light argument.
+    Each color is a lighter version of masterColor. This difference is
+    computed based on the number of keys.
 
     The masterColor is given in a hex string format.
     """
     r, g, b = hex2rgb(masterColor)
+    light = 1.0 / (len(keys)*2)
     return dict([(key, lighten(r, g, b, light * i))
                  for i, key in enumerate(keys)])
 
