@@ -1,4 +1,4 @@
-# Copyright (c) 2007 by Lorenzo Gil Sanchez <lorenzo.gil.sanchez@gmail.com>
+# Copyright (c) 2007-2008 by Lorenzo Gil Sanchez <lorenzo.gil.sanchez@gmail.com>
 #
 # This file is part of PyCha.
 #
@@ -59,7 +59,7 @@ class PieChart(Chart):
         """Evaluates pie ticks"""
         self.xticks = []
         if self.options.axis.x.ticks:
-            lookup = dict([(slice.xval, slice) for slice in self.slices])
+            lookup = dict([(slice.name, slice) for slice in self.slices])
             for tick in self.options.axis.x.ticks:
                 if not isinstance(tick, Option):
                     tick = Option(tick)
@@ -70,18 +70,24 @@ class PieChart(Chart):
                     self.xticks.append((tick.v, label))
         else:
             for slice in self.slices:
-                label = '%s (%.1f%%)' % (slice.xval, slice.fraction * 100)
-                self.xticks.append((slice.xval, label))
+                label = '%s (%.1f%%)' % (slice.name, slice.fraction * 100)
+                self.xticks.append((slice.name, label))
 
     def _renderBackground(self, cx):
         """Renders the background of the chart"""
         if self.options.background.hide:
             return
-        
+
         cx.save()
-        cx.set_source_rgb(*hex2rgb(self.options.background.color))
-        cx.rectangle(self.area.x, self.area.y, self.area.w, self.area.h)
-        cx.fill()
+
+        if self.options.background.baseColor:
+            cx.set_source_rgb(*hex2rgb(self.options.background.baseColor))
+            x, y, w, h = 0, 0, self.area.w, self.area.h
+            w += self.options.padding.left + self.options.padding.right
+            h += self.options.padding.top + self.options.padding.bottom
+            cx.rectangle(x, y, w, h)
+            cx.fill()
+
         cx.restore()
 
     def _renderChart(self, cx):
@@ -123,7 +129,7 @@ class PieChart(Chart):
             return
 
         self.xlabels = []
-        lookup = dict([(slice.xval, slice) for slice in self.slices])
+        lookup = dict([(slice.name, slice) for slice in self.slices])
 
         cx.set_source_rgb(*hex2rgb(self.options.axis.labelColor))
 
@@ -169,6 +175,10 @@ class Slice(object):
         self.startAngle = 2 * angle * math.pi
         self.endAngle = 2 * (angle + fraction) * math.pi
 
+    def __str__(self):
+        return ("<pycha.pie.Slice from %.2f to %.2f (%.2f%%)>" %
+                (self.startAngle, self.endAngle, self.fraction))
+
     def isBigEnough(self):
         return abs(self.startAngle - self.endAngle) > 0.001
 
@@ -180,7 +190,7 @@ class Slice(object):
                self.endAngle - math.pi/2)
         cx.line_to(centerx, centery)
         cx.close_path()
-    
+
     def getNormalisedAngle(self):
         normalisedAngle = (self.startAngle + self.endAngle) / 2
 
